#
# putnam-fishing.R, 17 Nov 24
#
# Data from:
# A General Empirical Solution to the Macro Software Sizing and Estimating Problem
# LAWRENCE H. PUTNAM
# Time-Sensitive Cost Models in the Commercial MIS Environment
# D. ROSS JEFFERY

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)


putnam=read.csv("Putnam_P-vs-D.csv")
put_us=subset(putnam, location == "US")
put_pa=subset(putnam, location == "Pacific")
put_eu=subset(putnam, location == "Europe")

jeff_DP=read.csv("Jeffery_D-vs-P.csv")
jeff_tK=read.csv("Jeffery_t-vs-K.csv")

plot(putnam$difficulty, putnam$productivity, log="xy",
	xlab="Difficulty", ylab="Productivity")

put_mod=glm(log(productivity) ~ log(difficulty), data=put_us)
summary(put_mod)

pred=predict(put_mod)
lines(put_us$difficulty, exp(pred), col="red")


# Now the Jeffery's data

plot(jeff_DP$difficulty, jeff_DP$productivity,
	xlab="log(Difficulty)", ylab="log(Productivity)")

# Extracted data is on a log scale
jpd_mod=glm(productivity ~ difficulty, data=jeff_DP)
summary(jpd_mod)

dev.copy(dev=png, file="jeffery_PD.png")
dev.off()


plot(jeff_tK$td, jeff_tK$K, col=pal_col[2], cex=1.3,
	xlab="log(t_d)", ylab="log(K)")

# Extracted data is on a log scale
jtk_mod=glm(K ~ td, data=jeff_tK)
summary(jtk_mod)

td_range=seq(0.4, 1.7, by=0.1)
pred=predict(jtk_mod, newdata=data.frame(td=td_range))

lines(td_range, pred, col=pal_col[1])

dev.copy(dev=png, file="jeffery_tK.png")
dev.off()


